# calibcant - tools for thermally calibrating AFM cantilevers
#
# Copyright (C) 2008-2010 W. Trevor King <wking@drexel.edu>
#
# This file is part of CalibCant.
#
# CalibCant is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# CalibCant is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with CalibCant.  If not, see
# <http://www.gnu.org/licenses/>.

"""Define some variables to configure the package for a particular lab
and workflow."""

import piezo.z_piezo as z_piezo


DEFAULT_TEMP = 22  # assume 22 deg C
LOG_DATA = True  # quietly grab all real-world data and log to LOG_DIR
LOG_DIR = '${DEFAULT}/calibrate_cantilever'
GNUFIT_DATA_BASE='./calibrate_cantilever_fitdata'
TEXT_VERBOSE = True      # for debugging
GNUPLOT_VERBOSE = True   # turn on fit check plotting
PYLAB_VERBOSE = True     # turn on plotting
PYLAB_INTERACTIVE = True # select between draw() and show() for flushing plots
BASE_FIGNUM = 20 # to avoid writing to already existing figures


# HACK
# make sure you make a system note (add_system_note) if you change
# these in case you don't have access to a z_piezo for conversion
# functions

# zpGain      zpiezo applied voltage per output Volt
zpGain = z_piezo.DEFAULT_GAIN
# zpSensitivity  nm zpiezo response per applied Volt
zpSensitivity = z_piezo.DEFAULT_SENSITIVITY
# Vzp_out2V   function that converts output DAC bits to Volts
Vzp_out2V = z_piezo.DEFAULT_VZP_OUT_2_VOLTS
# Vphoto_in2V function that converts input ADC bits to Volts
Vphoto_in2V = z_piezo.DEFAULT_VPHOTO_IN_2_VOLTS
# zeroVphoto_bits  ADC bit output for a 0V input
zeroVphoto_bits = z_piezo.DEFAULT_ZERO_PHOTODIODE_BITS
